@@ -50,6 +50,8 @@ func CreateGlobalConfig() config.Config {
 				regexp.MustCompile(`^\{\d{0,2}}$`),                       // Python (https://docs.python.org/3/tutorial/inputoutput.html)
 				// Urban Code Deploy (https://www.ibm.com/support/pages/replace-token-step-replaces-replacement-values-windows-variables)
 				regexp.MustCompile(`^@([A-Z_]+|[a-z_]+)@$`),
+
+				// ----------- Miscellaneous -----------
 			},
 			Paths: []*regexp.Regexp{
 				regexp.MustCompile(`gitleaks\.toml`),
@@ -71,7 +73,7 @@ func CreateGlobalConfig() config.Config {
 				regexp.MustCompile(`(^|/)mvnw(\.cmd)?$`),
 				regexp.MustCompile(`(^|/)\.mvn/wrapper/MavenWrapperDownloader\.java$`),
 
-				// ----------- Node.js files -----------
+				// ----------- JavaScript files -----------
 				// Dependencies and lock files.
 				regexp.MustCompile(`(^|/)node_modules/.*?$`),
 				regexp.MustCompile(`(^|/)package-lock\.json$`),
@@ -79,21 +81,15 @@ func CreateGlobalConfig() config.Config {
 				regexp.MustCompile(`(^|/)pnpm-lock\.yaml$`),
 				regexp.MustCompile(`(^|/)npm-shrinkwrap\.json$`),
 				regexp.MustCompile(`(^|/)bower_components/.*?$`),
+				// TODO: Add more common static assets, such as swagger-ui.
+				regexp.MustCompile(`(^|/)(jquery(-?ui)?|swagger-?ui)[a-zA-Z0-9.-]+\.js(\.map)?$`),
 
 				// ----------- Python files -----------
 				// Dependencies and lock files.
-				regexp.MustCompile(`(^|/)Pipfile\.lock$`),
-				regexp.MustCompile(`(^|/)poetry\.lock$`),
+				regexp.MustCompile(`(^|/)(Pipfile|poetry)\.lock$`),
 				// Virtual environments
-				// env/lib/python3.7/site-packages/urllib3/util/url.py
-				regexp.MustCompile(`(?i)/?(v?env|virtualenv)/lib/.+$`),
-				// /python/3.7.4/Lib/site-packages/dask/bytes/tests/test_bytes_utils.py
-				// python/3.7.4/Lib/site-packages/fsspec/utils.py
-				// python/2.7.16.32/Lib/bsddb/test/test_dbenv.py
-				regexp.MustCompile(`(?i)/?python/[23](\.\d{1,2})+/lib/.+$`),
-				// python/lib/python3.8/site-packages/boto3/data/ec2/2016-04-01/resources-1.json
-				// python/lib/python3.8/site-packages/botocore/data/alexaforbusiness/2017-11-09/service-2.json
-				regexp.MustCompile(`(?i)/?python/lib/python[23](\.\d{1,2})+/.+$`),
+				regexp.MustCompile(`(?i)/?(v?env|virtualenv)/lib(64)?/.+$`),
+				regexp.MustCompile(`(?i)(^|/)(lib(64)?/python[23](\.\d{1,2})+/|python/[23](\.\d{1,2})+/lib(64)?/).+$`),
 				// dist-info directory (https://py-pkgs.org/04-package-structure.html#building-sdists-and-wheels)
 				regexp.MustCompile(`(?i)(^|/)[a-z0-9_.]+-[0-9.]+\.dist-info/.+$`),
 
@@ -106,6 +102,11 @@ func CreateGlobalConfig() config.Config {
 				regexp.MustCompile(`Database.refactorlog`),
 				//regexp.MustCompile(`vendor`),
 			},
+			StopWords: []string{
+				// ----------- Secrets -----------
+				// Checkmarx client secret. (https://github.com/checkmarx-ts/checkmarx-python-sdk/blob/86560f6e2a3e46d16322101294da10d5d190312d/README.md?plain=1#L56)
+				"014df517-39d1-4453-b7b3-9930c563627c",
+			},
 		},
 	}
 }
