@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,14 +11,14 @@ func Contentful() *config.Rule {
 	r := config.Rule{
 		Description: "Discovered a Contentful delivery API token, posing a risk to content management systems and data integrity.",
 		RuleID:      "contentful-delivery-api-token",
-		Regex: generateSemiGenericRegex([]string{"contentful"},
-			alphaNumericExtended("43"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"contentful"},
+			utils.AlphaNumericExtended("43"), true),
 		Keywords: []string{"contentful"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("contentful", secrets.NewSecret(alphaNumeric("43"))),
+		utils.GenerateSampleSecret("contentful", secrets.NewSecret(utils.AlphaNumeric("43"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
