@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,8 +11,8 @@ func DatadogtokenAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "datadog-access-token",
 		Description: "Detected a Datadog Access Token, potentially risking monitoring and analytics data exposure and manipulation.",
-		Regex: generateSemiGenericRegex([]string{"datadog"},
-			alphaNumeric("40"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"datadog"},
+			utils.AlphaNumeric("40"), true),
 		Keywords: []string{
 			"datadog",
 		},
@@ -19,7 +20,7 @@ func DatadogtokenAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("datadog", secrets.NewSecret(alphaNumeric("40"))),
+		utils.GenerateSampleSecret("datadog", secrets.NewSecret(utils.AlphaNumeric("40"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
