@@ -8,9 +8,10 @@ import (
 
 func DigitalOceanPAT() *config.Rule {
 	r := config.Rule{
-		Description: "Discovered a DigitalOcean Personal Access Token, posing a threat to cloud infrastructure security and data privacy.",
 		RuleID:      "digitalocean-pat",
-		Regex:       utils.GenerateUniqueTokenRegex(`dop_v1_[a-f0-9]{64}`, true),
+		Description: "Discovered a DigitalOcean Personal Access Token, posing a threat to cloud infrastructure security and data privacy.",
+		Regex:       utils.GenerateUniqueTokenRegex(`dop_v1_[a-f0-9]{64}`, false),
+		Entropy:     3,
 		Keywords:    []string{"dop_v1_"},
 	}
 
@@ -22,11 +23,11 @@ func DigitalOceanPAT() *config.Rule {
 
 func DigitalOceanOAuthToken() *config.Rule {
 	r := config.Rule{
-		Description: "Found a DigitalOcean OAuth Access Token, risking unauthorized cloud resource access and data compromise.",
 		RuleID:      "digitalocean-access-token",
-
-		Regex:    utils.GenerateUniqueTokenRegex(`doo_v1_[a-f0-9]{64}`, true),
-		Keywords: []string{"doo_v1_"},
+		Description: "Found a DigitalOcean OAuth Access Token, risking unauthorized cloud resource access and data compromise.",
+		Entropy:     3,
+		Regex:       utils.GenerateUniqueTokenRegex(`doo_v1_[a-f0-9]{64}`, false),
+		Keywords:    []string{"doo_v1_"},
 	}
 
 	tps := []string{
