@@ -9,8 +9,8 @@ import (
 func DiscordAPIToken() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Detected a Discord API key, potentially compromising communication channels and user data privacy on Discord.",
 		RuleID:      "discord-api-token",
+		Description: "Detected a Discord API key, potentially compromising communication channels and user data privacy on Discord.",
 		Regex:       utils.GenerateSemiGenericRegex([]string{"discord"}, utils.Hex("64"), true),
 		Keywords:    []string{"discord"},
 	}
@@ -25,9 +25,10 @@ func DiscordAPIToken() *config.Rule {
 func DiscordClientID() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Identified a Discord client ID, which may lead to unauthorized integrations and data exposure in Discord applications.",
 		RuleID:      "discord-client-id",
+		Description: "Identified a Discord client ID, which may lead to unauthorized integrations and data exposure in Discord applications.",
 		Regex:       utils.GenerateSemiGenericRegex([]string{"discord"}, utils.Numeric("18"), true),
+		Entropy:     2,
 		Keywords:    []string{"discord"},
 	}
 
@@ -35,15 +36,20 @@ func DiscordClientID() *config.Rule {
 	tps := []string{
 		utils.GenerateSampleSecret("discord", secrets.NewSecret(utils.Numeric("18"))),
 	}
-	return utils.Validate(r, tps, nil)
+	fps := []string{
+		// Low entropy
+		`discord=000000000000000000`,
+	}
+	return utils.Validate(r, tps, fps)
 }
 
 func DiscordClientSecret() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Discovered a potential Discord client secret, risking compromised Discord bot integrations and data leaks.",
 		RuleID:      "discord-client-secret",
+		Description: "Discovered a potential Discord client secret, risking compromised Discord bot integrations and data leaks.",
 		Regex:       utils.GenerateSemiGenericRegex([]string{"discord"}, utils.AlphaNumericExtended("32"), true),
+		Entropy:     2,
 		Keywords:    []string{"discord"},
 	}
 
@@ -51,5 +57,11 @@ func DiscordClientSecret() *config.Rule {
 	tps := []string{
 		utils.GenerateSampleSecret("discord", secrets.NewSecret(utils.Numeric("32"))),
 	}
-	return utils.Validate(r, tps, nil)
+	fps := []string{
+		// Low entropy
+		`discord=00000000000000000000000000000000`,
+		// TODO:
+		//`discord=01234567890123456789012345678901`,
+	}
+	return utils.Validate(r, tps, fps)
 }
