@@ -11,10 +11,11 @@ import (
 func Doppler() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Discovered a Doppler API token, posing a risk to environment and secrets management security.",
 		RuleID:      "doppler-api-token",
+		Description: "Discovered a Doppler API token, posing a risk to environment and secrets management security.",
 		Regex:       regexp.MustCompile(`dp\.pt\.(?i)[a-z0-9]{43}`),
-		Keywords:    []string{"doppler"},
+		Entropy:     2,
+		Keywords:    []string{`dp.pt.`},
 	}
 
 	// validate
