@@ -14,7 +14,8 @@ func Duffel() *config.Rule {
 		RuleID:      "duffel-api-token",
 		Description: "Uncovered a Duffel API token, which may compromise travel platform integrations and sensitive customer data.",
 		Regex:       regexp.MustCompile(`duffel_(?:test|live)_(?i)[a-z0-9_\-=]{43}`),
-		Keywords:    []string{"duffel"},
+		Entropy:     2,
+		Keywords:    []string{"duffel_"},
 	}
 
 	// validate
