@@ -11,10 +11,11 @@ import (
 func Dynatrace() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Detected a Dynatrace API token, potentially risking application performance monitoring and data exposure.",
 		RuleID:      "dynatrace-api-token",
+		Description: "Detected a Dynatrace API token, potentially risking application performance monitoring and data exposure.",
 		Regex:       regexp.MustCompile(`dt0c01\.(?i)[a-z0-9]{24}\.[a-z0-9]{64}`),
-		Keywords:    []string{"dynatrace"},
+		Entropy:     4,
+		Keywords:    []string{"dt0c01"},
 	}
 
 	// validate
