@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,16 +11,16 @@ func FinicityClientSecret() *config.Rule {
 	r := config.Rule{
 		Description: "Identified a Finicity Client Secret, which could lead to compromised financial service integrations and data breaches.",
 		RuleID:      "finicity-client-secret",
-		Regex:       generateSemiGenericRegex([]string{"finicity"}, alphaNumeric("20"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"finicity"}, utils.AlphaNumeric("20"), true),
 
 		Keywords: []string{"finicity"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("finicity", secrets.NewSecret(alphaNumeric("20"))),
+		utils.GenerateSampleSecret("finicity", secrets.NewSecret(utils.AlphaNumeric("20"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
 
 func FinicityAPIToken() *config.Rule {
@@ -27,14 +28,14 @@ func FinicityAPIToken() *config.Rule {
 	r := config.Rule{
 		Description: "Detected a Finicity API token, potentially risking financial data access and unauthorized financial operations.",
 		RuleID:      "finicity-api-token",
-		Regex:       generateSemiGenericRegex([]string{"finicity"}, hex("32"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"finicity"}, utils.Hex("32"), true),
 
 		Keywords: []string{"finicity"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("finicity", secrets.NewSecret(hex("32"))),
+		utils.GenerateSampleSecret("finicity", secrets.NewSecret(utils.Hex("32"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
