@@ -8,14 +8,24 @@ import (
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
+var githubAllowlist = []config.Allowlist{
+	{
+		Paths: []*regexp.Regexp{
+			// https://github.com/octokit/auth-token.js/?tab=readme-ov-file#createtokenauthtoken-options
+			regexp.MustCompile(`(^|/)@octokit/auth-token/README\.md$`),
+		},
+	},
+}
+
 func GitHubPat() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Uncovered a GitHub Personal Access Token, potentially leading to unauthorized repository access and sensitive content exposure.",
 		RuleID:      "github-pat",
+		Description: "Uncovered a GitHub Personal Access Token, potentially leading to unauthorized repository access and sensitive content exposure.",
 		Regex:       regexp.MustCompile(`ghp_[0-9a-zA-Z]{36}`),
 		Entropy:     3,
 		Keywords:    []string{"ghp_"},
+		Allowlists:  githubAllowlist,
 	}
 
 	// validate
@@ -31,8 +41,8 @@ func GitHubPat() *config.Rule {
 func GitHubFineGrainedPat() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Found a GitHub Fine-Grained Personal Access Token, risking unauthorized repository access and code manipulation.",
 		RuleID:      "github-fine-grained-pat",
+		Description: "Found a GitHub Fine-Grained Personal Access Token, risking unauthorized repository access and code manipulation.",
 		Regex:       regexp.MustCompile(`github_pat_\w{82}`),
 		Entropy:     3,
 		Keywords:    []string{"github_pat_"},
@@ -51,8 +61,8 @@ func GitHubFineGrainedPat() *config.Rule {
 func GitHubOauth() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Discovered a GitHub OAuth Access Token, posing a risk of compromised GitHub account integrations and data leaks.",
 		RuleID:      "github-oauth",
+		Description: "Discovered a GitHub OAuth Access Token, posing a risk of compromised GitHub account integrations and data leaks.",
 		Regex:       regexp.MustCompile(`gho_[0-9a-zA-Z]{36}`),
 		Entropy:     3,
 		Keywords:    []string{"gho_"},
@@ -71,11 +81,12 @@ func GitHubOauth() *config.Rule {
 func GitHubApp() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Identified a GitHub App Token, which may compromise GitHub application integrations and source code security.",
 		RuleID:      "github-app-token",
+		Description: "Identified a GitHub App Token, which may compromise GitHub application integrations and source code security.",
 		Regex:       regexp.MustCompile(`(?:ghu|ghs)_[0-9a-zA-Z]{36}`),
 		Entropy:     3,
 		Keywords:    []string{"ghu_", "ghs_"},
+		Allowlists:  githubAllowlist,
 	}
 
 	// validate
@@ -93,8 +104,8 @@ func GitHubApp() *config.Rule {
 func GitHubRefresh() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Detected a GitHub Refresh Token, which could allow prolonged unauthorized access to GitHub services.",
 		RuleID:      "github-refresh-token",
+		Description: "Detected a GitHub Refresh Token, which could allow prolonged unauthorized access to GitHub services.",
 		Regex:       regexp.MustCompile(`ghr_[0-9a-zA-Z]{36}`),
 		Entropy:     3,
 		Keywords:    []string{"ghr_"},
