@@ -11,8 +11,8 @@ func Prefect() *config.Rule {
 	r := config.Rule{
 		RuleID:      "prefect-api-token",
 		Description: "Detected a Prefect API token, risking unauthorized access to workflow management and automation services.",
-		Regex:       utils.GenerateUniqueTokenRegex(`pnu_[a-z0-9]{36}`, true),
-
+		Regex:       utils.GenerateUniqueTokenRegex(`pnu_[a-zA-Z0-9]{36}`, false),
+		Entropy:     2,
 		Keywords: []string{
 			"pnu_",
 		},
@@ -22,5 +22,8 @@ func Prefect() *config.Rule {
 	tps := []string{
 		utils.GenerateSampleSecret("api-token", "pnu_"+secrets.NewSecret(utils.AlphaNumeric("36"))),
 	}
-	return utils.Validate(r, tps, nil)
+	fps := []string{
+		`PREFECT_API_KEY = "pnu_XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"`,
+	}
+	return utils.Validate(r, tps, fps)
 }
