@@ -11,8 +11,8 @@ func SendInBlueAPIToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "sendinblue-api-token",
 		Description: "Identified a Sendinblue API token, which may compromise email marketing services and subscriber data privacy.",
-		Regex:       utils.GenerateUniqueTokenRegex(`xkeysib-[a-f0-9]{64}\-(?i)[a-z0-9]{16}`, true),
-
+		Regex:       utils.GenerateUniqueTokenRegex(`xkeysib-[a-f0-9]{64}\-(?i)[a-z0-9]{16}`, false),
+		Entropy:     2,
 		Keywords: []string{
 			"xkeysib-",
 		},
