@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func SentryAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "sentry-access-token",
 		Description: "Found a Sentry Access Token, risking unauthorized access to error tracking services and sensitive application data.",
-		Regex:       generateSemiGenericRegex([]string{"sentry"}, hex("64"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"sentry"}, utils.Hex("64"), true),
 
 		Keywords: []string{
 			"sentry",
@@ -19,7 +20,7 @@ func SentryAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("sentry", secrets.NewSecret(hex("64"))),
+		utils.GenerateSampleSecret("sentry", secrets.NewSecret(utils.Hex("64"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
