@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func SquareSpaceAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "squarespace-access-token",
 		Description: "Identified a Squarespace Access Token, which may compromise website management and content control on Squarespace.",
-		Regex:       generateSemiGenericRegex([]string{"squarespace"}, hex8_4_4_4_12(), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"squarespace"}, utils.Hex8_4_4_4_12(), true),
 
 		Keywords: []string{
 			"squarespace",
@@ -19,7 +20,7 @@ func SquareSpaceAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("squarespace", secrets.NewSecret(hex8_4_4_4_12())),
+		utils.GenerateSampleSecret("squarespace", secrets.NewSecret(utils.Hex8_4_4_4_12())),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
