@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func TravisCIAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "travisci-access-token",
 		Description: "Identified a Travis CI Access Token, potentially compromising continuous integration services and codebase security.",
-		Regex:       generateSemiGenericRegex([]string{"travis"}, alphaNumeric("22"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"travis"}, utils.AlphaNumeric("22"), true),
 
 		Keywords: []string{
 			"travis",
@@ -19,7 +20,7 @@ func TravisCIAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("travis", secrets.NewSecret(alphaNumeric("22"))),
+		utils.GenerateSampleSecret("travis", secrets.NewSecret(utils.AlphaNumeric("22"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
