@@ -11,10 +11,11 @@ import (
 func Twilio() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Found a Twilio API Key, posing a risk to communication services and sensitive customer interaction data.",
 		RuleID:      "twilio-api-key",
+		Description: "Found a Twilio API Key, posing a risk to communication services and sensitive customer interaction data.",
 		Regex:       regexp.MustCompile(`SK[0-9a-fA-F]{32}`),
-		Keywords:    []string{"twilio"},
+		Entropy:     3,
+		Keywords:    []string{"SK"},
 	}
 
 	// validate
