@@ -1,12 +1,12 @@
 package sources
 
 import (
+	"github.com/rs/zerolog/log"
 	"io/fs"
 	"os"
 	"path/filepath"
 
 	"github.com/fatih/semgroup"
-	"github.com/rs/zerolog/log"
 )
 
 type ScanTarget struct {
@@ -35,7 +35,12 @@ func DirectoryTargets(source string, s *semgroup.Group, followSymlinks bool) (<-
 						Symlink: "",
 					}
 				}
-				if fInfo.Mode().Type() == fs.ModeSymlink && followSymlinks {
+				if fInfo.Mode().Type() == fs.ModeSymlink {
+					if !followSymlinks {
+						log.Debug().Str("path", path).Msg("Skipping symlink")
+						return nil
+					}
+
 					realPath, err := filepath.EvalSymlinks(path)
 					if err != nil {
 						return err
